@@ -43,6 +43,7 @@ BlockReflowInput::BlockReflowInput(const ReflowInput& aReflowInput,
     mOverflowTracker(nullptr),
     mBorderPadding(mReflowInput.ComputedLogicalBorderPadding()),
     mPrevBEndMargin(),
+    mMinLineHeight(aReflowInput.GetLineHeight()),
     mLineNumber(0),
     mFloatBreakType(StyleClear::None),
     mConsumedBSize(aConsumedBSize)
@@ -141,8 +142,6 @@ BlockReflowInput::BlockReflowInput(const ReflowInput& aReflowInput,
 
   mPrevChild = nullptr;
   mCurrentLine = aFrame->LinesEnd();
-
-  mMinLineHeight = aReflowInput.CalcLineHeight();
 }
 
 nscoord
